netapp_ontap.models.zapp_nvme API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.zapp_nvme`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ZappNvmeSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ZappNvme object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `components GET POST PATCH`

    The components field of the zapp_nvme.

  `os_type GET POST`

    The name of the host OS running the application.

    Valid choices:

    - linux
    - vmware
    - windows
  `rpo GET POST PATCH`

    The rpo field of the zapp_nvme.